from setuptools import setup

setup(name='gauss-bio-dist',
      version='1.4',
      description='Gaussian and Binomial distributions',
      packages=['gauss-bio-dist'],
      author='Ensiyeh Raoufi',
      author_email='raoufien@gmail.com',
      zip_safe=False)
